==> 0.0.42.tar.gz: lib/model/faceToFaceModel.dart <==
import 'dart:typed_data';

import 'package:crypto_keys/crypto_keys.dart';

import '../beevoter_comm.dart';
import '../beevoter_crypto.dart';
import 'controller.dart';
import 'model.dart';
import 'dart:convert';

class BeeVoterQRCode {
	String url;
	String userContact;
	CredentialType userContactType;

	BeeVoterQRCode(String scan) {
		Map<String, dynamic> json = jsonDecode(scan);
		url = json['url'];
		userContact = json['userContact'];
		var userContactType = json['userContactType'];
		switch(userContactType) {
			case 0:
				this.userContactType = CredentialType.email();
				break;
			case 1:
				this.userContactType = CredentialType.email();
				break;
			case 2:
				this.userContactType = CredentialType.document();
				break;
		}
	}
}
class BallotBoxQRCode {
	String ip;
	int port;

	BallotBoxQRCode(this.ip, this.port);
	static BallotBoxQRCode fromJson(String scan) {
		Map<String, dynamic> json = jsonDecode(scan);
		return new BallotBoxQRCode(json['ip'], json['port']);
	}
	String toQRCode() {
		var json = new Map<String, dynamic>();
		json['ip'] = ip;
		json['port'] = port;
		return jsonEncode(json);
	}
}
abstract class PoolStationAction extends ConnectionAction {
	ConnectionInfo _ballotBoxConnectionInfo;
	BeeVoterController beeVoterController;

	bool connected() {
		return beeVoterController != null;
	}
	PoolStationAction(ConnectionInfo connectionInfo) {
		this._ballotBoxConnectionInfo = connectionInfo;
		_ballotBoxConnectionInfo.createConnection(this);
	}
	Future connectToBeevoter(BeeVoterQRCode qrcode, String password) async {
		this.beeVoterController = new BeeVoterController(qrcode.url);
		await this.beeVoterController.startConnection();
		await this.beeVoterController.login(qrcode.userContact, qrcode.userContactType , password);
	}

	Future onReceive(String localIp, int commandType, String command) async {
		switch(commandType) {
			case FaceToFaceCommand.requestBallotBoxConfiguration:
				// var cmd = RequestBallotBoxConfiguration.create(string2JsModel(command));
				initializeBallotBox(lastPoolWorkerPassword, lastPoolingStationId, lastPoolingStationPort);
				break;
			case FaceToFaceCommand.setBallotBoxStatus:
				setBallotBoxStatus(SetBallotBoxStatus.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.castVote:
				castVote(CastVote.create(string2JsModel(command)));
				break;
		}
	}
	Future onConnectionClosed(String localIp) async {
		// finishBallotBox();
	}

	String lastPoolWorkerPassword;
	String lastPoolingStationId;
	int lastPoolingStationPort;
	void initializeBallotBox(String poolWorkerPassword, String poolingStationId, int poolingStationPort) {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		lastPoolWorkerPassword = poolWorkerPassword;
		lastPoolingStationId = poolingStationId;
		lastPoolingStationPort = poolingStationPort;
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.initializeBallotBox, jsModel2String(new InitializeBallotBox(beeVoterController.initializeResponse, poolWorkerPassword, poolingStationId, poolingStationPort).toJson()));
	}
	void getBallotBoxStatus() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.getBallotBoxStatus, jsModel2String(new GetBallotBoxStatus().toJson()));
	}
	void sendVoterToBallotBox(VoterModel voter) {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.sendVoterToBallotBox, jsModel2String(new VoterToBallotBox(voter).toJson()));
	}
	void cancelVote() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.cancelVote, jsModel2String(new CancelVote().toJson()));
	}
	void finishBallotBox() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.finishBallotBox, jsModel2String(new FinishBallotBox().toJson()));
	}
	void setBallotBoxStatus(SetBallotBoxStatus cmd);
	void castVote(CastVote cmd);
}
abstract class BallotBoxAction extends ConnectionAction {
	ConnectionInfo _poolingStationConnectionInfo;
	InitializeResponse initializeResponse;
	int lastStatus = 0;

	BallotBoxAction(ConnectionInfo connectionInfo) {
		this._poolingStationConnectionInfo = connectionInfo;
		_poolingStationConnectionInfo.createConnection(this);
	}

	Future onReceive(String localIp, int commandType, String command) async {
		switch(commandType) {
			case FaceToFaceCommand.initializeBallotBox:
				var cmd = InitializeBallotBox.create(string2JsModel(command));
				this.initializeResponse = cmd.initializeResponse;
				onInitialized(cmd);
				break;
			case FaceToFaceCommand.getBallotBoxStatus:
				// var cmd = GetBallotBoxStatus.create(string2JsModel(command));
				setBallotBoxStatus(lastStatus);
				break;
			case FaceToFaceCommand.sendVoterToBallotBox:
				onVoterToBallotBox(VoterToBallotBox.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.cancelVote:
				onCancelVote(CancelVote.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.finishBallotBox:
				onFinishBallotBox(FinishBallotBox.create(string2JsModel(command)));
				break;
		}
	}
	Future onConnectionClosed(String localIp) async {
	}
	void castVote(CastVote vote) {
		if (initializeResponse == null)
			throw new Exception('Not initialized');
		_poolingStationConnectionInfo.send(FaceToFaceCommand.castVote, jsModel2String(vote.toJson()));
	}
	void setBallotBoxStatus(int status) {
		this.lastStatus = status;
		if (initializeResponse == null)
			throw new Exception('Not initialized');
		_poolingStationConnectionInfo.send(FaceToFaceCommand.setBallotBoxStatus, jsModel2String(new SetBallotBoxStatus(status).toJson()));
	}
	void onVoterToBallotBox(VoterToBallotBox cmd);
	void onInitialized(InitializeBallotBox cmd);
	void onCancelVote(CancelVote cmd);
	void onFinishBallotBox(FinishBallotBox cmd);

	Future<CastVotesRequestModel> createVoteModel(int voterId, KeyPairInfoModel voterKeyPair, String password, List<VoteToBeCast> votesToBeCast) async {
		var organizationKeyPair = CommonCrypto.getPublicKeyByKeyPair(this.initializeResponse.organization.privateKey);
		var votes = new CastVotesRequestModel(voterId: voterId, votes: []);
		for(var i=0; i<votesToBeCast.length; i++)
			votes.votes.add(await createPoolVote(organizationKeyPair, voterKeyPair, password, votesToBeCast[i].pool, votesToBeCast[i].voterPoolId, votesToBeCast[i].votes));
		return votes;
	}
	Future<VoteModel> createPoolVote(KeyPair organizationKeyPair, KeyPairInfoModel voterKeyPair, String password, PoolModel pool, int voterPoolId, List<PoolOptionModel> voteOptions) async {
		var openVotes = '';
		for(var i=0; i<voteOptions.length; i++) {
			if (i>0)
				openVotes += ';';
			openVotes += voteOptions[i].id.toString();
		}
		var encryptedVote = CommonCrypto.rsaEncrypt(organizationKeyPair, new Uint8List.fromList(openVotes.codeUnits));
		var voteSignature = await CommonCrypto.signFromPkcs12(password, voterKeyPair.pinSalt, voterKeyPair.iterationCount, voterKeyPair.pkcs12, encryptedVote.data);
		var reqString = CommonCrypto.getRandomString(10);
		var req = CommonCrypto.calculateSha256(reqString);
		return new VoteModel(
			voterId: voterPoolId,
			poolId: pool.id,
			encryptedVote: base64Encode(encryptedVote.data),
			openVote: pool.isSecret ? '' : openVotes,
			signature: base64Encode(voteSignature),
			receiptRequest: req,
			voterKeyId: voterKeyPair.id,
		);
	}
}
abstract class FaceToFaceCommand {
	static const int requestBallotBoxConfiguration=1;
	static const int initializeBallotBox=2;
	static const int getBallotBoxStatus=3;
	static const int setBallotBoxStatus=4;
	static const int sendVoterToBallotBox=5;
	static const int castVote=6;
	static const int cancelVote=7;
	static const int finishBallotBox=8;

	String signature;
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = new Map<String, dynamic>();
		json['id'] = this.signature;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		this.signature = json['id'];
	}

	static FaceToFaceCommand create(FaceToFaceCommand command, Map<String, dynamic> json) {
		if (json != null) command.fromJson(json);
		return command;
	}
}
class RequestBallotBoxConfiguration extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static RequestBallotBoxConfiguration create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new RequestBallotBoxConfiguration(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class InitializeBallotBox extends FaceToFaceCommand {
	InitializeResponse initializeResponse;
	AuthenticatedUserModel currentUser;
	String poolWorkerPassword;
	String poolingStationId;
	int poolingStationPort;

	InitializeBallotBox(this.initializeResponse, this.poolWorkerPassword, this.poolingStationId, this.poolingStationPort);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['initializeResponse'] = this.initializeResponse.toJson();
		json['currentUser'] = this.currentUser.toJson();
		json['poolWorkerPassword'] = this.poolWorkerPassword;
		json['poolingStationId'] = this.poolingStationId;
		json['poolingStationPort'] = this.poolingStationPort;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.initializeResponse = InitializeResponse.create(json['initializeResponse']);
		this.currentUser = AuthenticatedUserModel.create(json['currentUser']);
		this.poolWorkerPassword = json['poolWorkerPassword'];
		this.poolingStationId = json['poolingStationId'];
		this.poolingStationPort = json['poolingStationPort'];
	}

	static InitializeBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new InitializeBallotBox(null,null,null,-1), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class GetBallotBoxStatus extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static GetBallotBoxStatus create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new GetBallotBoxStatus(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class SetBallotBoxStatus extends FaceToFaceCommand {
	int status;
	SetBallotBoxStatus(this.status);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['status'] = this.status;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.status = json['status'];
	}

	static SetBallotBoxStatus create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new SetBallotBoxStatus(0), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class VoterToBallotBox extends FaceToFaceCommand {
	VoterModel voter;
	VoterToBallotBox(this.voter);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['voter'] = this.voter.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.voter = VoterModel.create(json['voter']);
	}

	static VoterToBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new VoterToBallotBox(null), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class CastVote extends FaceToFaceCommand {
	CastVotesRequestModel vote;

	CastVote(this.vote);
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['vote'] = this.vote.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.vote = CastVotesRequestModel.create(json['vote']);
	}

	static CastVote create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new CastVote(null), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class CancelVote extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static CancelVote create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new CancelVote(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class FinishBallotBox extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static FinishBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new FinishBallotBox(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}

==> 0.0.45.tar.gz: lib/model/faceToFaceModel.dart <==
import 'dart:typed_data';

import 'package:crypto_keys/crypto_keys.dart';

import '../beevoter_comm.dart';
import '../beevoter_crypto.dart';
import 'controller.dart';
import 'model.dart';
import 'dart:convert';

class BeeVoterQRCode {
	String url;
	String userContact;
	CredentialType userContactType;

	BeeVoterQRCode(String scan) {
		Map<String, dynamic> json = jsonDecode(scan);
		url = json['url'];
		userContact = json['userContact'];
		var userContactType = json['userContactType'];
		switch(userContactType) {
			case 0:
				this.userContactType = CredentialType.email();
				break;
			case 1:
				this.userContactType = CredentialType.email();
				break;
			case 2:
				this.userContactType = CredentialType.document();
				break;
		}
	}
}
class BallotBoxQRCode {
	String ip;
	int port;

	BallotBoxQRCode(this.ip, this.port);
	static BallotBoxQRCode fromJson(String scan) {
		Map<String, dynamic> json = jsonDecode(scan);
		return new BallotBoxQRCode(json['ip'], json['port']);
	}
	String toQRCode() {
		var json = new Map<String, dynamic>();
		json['ip'] = ip;
		json['port'] = port;
		return jsonEncode(json);
	}
}
abstract class PoolStationAction extends ConnectionAction {
	ConnectionInfo _ballotBoxConnectionInfo;
	BeeVoterController beeVoterController;

	bool connected() {
		return beeVoterController != null;
	}
	PoolStationAction(ConnectionInfo connectionInfo) {
		this._ballotBoxConnectionInfo = connectionInfo;
		_ballotBoxConnectionInfo.createConnection(this);
	}
	Future connectToBeevoter(BeeVoterQRCode qrcode, String password) async {
		this.beeVoterController = new BeeVoterController(qrcode.url);
		await this.beeVoterController.startConnection();
		await this.beeVoterController.login(qrcode.userContact, qrcode.userContactType , password);
	}

	Future onReceive(String localIp, int commandType, String command) async {
		switch(commandType) {
			case FaceToFaceCommand.requestBallotBoxConfiguration:
				// var cmd = RequestBallotBoxConfiguration.create(string2JsModel(command));
				initializeBallotBox(lastPoolWorkerPassword, lastPoolingStationId, lastPoolingStationPort);
				break;
			case FaceToFaceCommand.setBallotBoxStatus:
				setBallotBoxStatus(SetBallotBoxStatus.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.castVote:
				castVote(CastVote.create(string2JsModel(command)));
				break;
		}
	}
	Future onConnectionClosed(String localIp) async {
		// finishBallotBox();
	}

	String lastPoolWorkerPassword;
	String lastPoolingStationId;
	int lastPoolingStationPort;
	void initializeBallotBox(String poolWorkerPassword, String poolingStationId, int poolingStationPort) {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		lastPoolWorkerPassword = poolWorkerPassword;
		lastPoolingStationId = poolingStationId;
		lastPoolingStationPort = poolingStationPort;
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.initializeBallotBox, jsModel2String(new InitializeBallotBox(beeVoterController.initializeResponse, beeVoterController.currentUser, poolWorkerPassword, poolingStationId, poolingStationPort).toJson()));
	}
	void getBallotBoxStatus() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.getBallotBoxStatus, jsModel2String(new GetBallotBoxStatus().toJson()));
	}
	void sendVoterToBallotBox(VoterModel voter) {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.sendVoterToBallotBox, jsModel2String(new VoterToBallotBox(voter).toJson()));
	}
	void cancelVote() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.cancelVote, jsModel2String(new CancelVote().toJson()));
	}
	void finishBallotBox() {
		if (beeVoterController == null || beeVoterController.initializeResponse == null)
			throw new Exception('Not initialized');
		_ballotBoxConnectionInfo.send(FaceToFaceCommand.finishBallotBox, jsModel2String(new FinishBallotBox().toJson()));
	}
	void setBallotBoxStatus(SetBallotBoxStatus cmd);
	void castVote(CastVote cmd);
}
abstract class BallotBoxAction extends ConnectionAction {
	ConnectionInfo _poolingStationConnectionInfo;
	InitializeResponse initializeResponse;
	int lastStatus = 0;

	BallotBoxAction(ConnectionInfo connectionInfo) {
		this._poolingStationConnectionInfo = connectionInfo;
		_poolingStationConnectionInfo.createConnection(this);
	}

	Future onReceive(String localIp, int commandType, String command) async {
		switch(commandType) {
			case FaceToFaceCommand.initializeBallotBox:
				var cmd = InitializeBallotBox.create(string2JsModel(command));
				this.initializeResponse = cmd.initializeResponse;
				onInitialized(cmd);
				break;
			case FaceToFaceCommand.getBallotBoxStatus:
				// var cmd = GetBallotBoxStatus.create(string2JsModel(command));
				setBallotBoxStatus(lastStatus);
				break;
			case FaceToFaceCommand.sendVoterToBallotBox:
				onVoterToBallotBox(VoterToBallotBox.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.cancelVote:
				onCancelVote(CancelVote.create(string2JsModel(command)));
				break;
			case FaceToFaceCommand.finishBallotBox:
				onFinishBallotBox(FinishBallotBox.create(string2JsModel(command)));
				break;
		}
	}
	Future onConnectionClosed(String localIp) async {
	}
	void castVote(CastVote vote) {
		if (initializeResponse == null)
			throw new Exception('Not initialized');
		_poolingStationConnectionInfo.send(FaceToFaceCommand.castVote, jsModel2String(vote.toJson()));
	}
	void setBallotBoxStatus(int status) {
		this.lastStatus = status;
		if (initializeResponse == null)
			throw new Exception('Not initialized');
		_poolingStationConnectionInfo.send(FaceToFaceCommand.setBallotBoxStatus, jsModel2String(new SetBallotBoxStatus(status).toJson()));
	}
	void onVoterToBallotBox(VoterToBallotBox cmd);
	void onInitialized(InitializeBallotBox cmd);
	void onCancelVote(CancelVote cmd);
	void onFinishBallotBox(FinishBallotBox cmd);

	Future<CastVotesRequestModel> createVoteModel(int voterId, KeyPairInfoModel voterKeyPair, String password, List<VoteToBeCast> votesToBeCast) async {
		var organizationKeyPair = CommonCrypto.getPublicKeyByKeyPair(this.initializeResponse.organization.privateKey);
		var votes = new CastVotesRequestModel(voterId: voterId, votes: []);
		for(var i=0; i<votesToBeCast.length; i++)
			votes.votes.add(await createPoolVote(organizationKeyPair, voterKeyPair, password, votesToBeCast[i].pool, votesToBeCast[i].voterPoolId, votesToBeCast[i].votes));
		return votes;
	}
	Future<VoteModel> createPoolVote(KeyPair organizationKeyPair, KeyPairInfoModel voterKeyPair, String password, PoolModel pool, int voterPoolId, List<PoolOptionModel> voteOptions) async {
		var openVotes = '';
		for(var i=0; i<voteOptions.length; i++) {
			if (i>0)
				openVotes += ';';
			openVotes += voteOptions[i].id.toString();
		}
		var encryptedVote = CommonCrypto.rsaEncrypt(organizationKeyPair, new Uint8List.fromList(openVotes.codeUnits));
		var voteSignature = await CommonCrypto.signFromPkcs12(password, voterKeyPair.pinSalt, voterKeyPair.iterationCount, voterKeyPair.pkcs12, encryptedVote.data);
		var reqString = CommonCrypto.getRandomString(10);
		var req = CommonCrypto.calculateSha256(reqString);
		return new VoteModel(
			voterId: voterPoolId,
			poolId: pool.id,
			encryptedVote: base64Encode(encryptedVote.data),
			openVote: pool.isSecret ? '' : openVotes,
			signature: base64Encode(voteSignature),
			receiptRequest: req,
			voterKeyId: voterKeyPair.id,
		);
	}
}
abstract class FaceToFaceCommand {
	static const int requestBallotBoxConfiguration=1;
	static const int initializeBallotBox=2;
	static const int getBallotBoxStatus=3;
	static const int setBallotBoxStatus=4;
	static const int sendVoterToBallotBox=5;
	static const int castVote=6;
	static const int cancelVote=7;
	static const int finishBallotBox=8;

	String signature;
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = new Map<String, dynamic>();
		json['id'] = this.signature;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		this.signature = json['id'];
	}

	static FaceToFaceCommand create(FaceToFaceCommand command, Map<String, dynamic> json) {
		if (json != null) command.fromJson(json);
		return command;
	}
}
class RequestBallotBoxConfiguration extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static RequestBallotBoxConfiguration create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new RequestBallotBoxConfiguration(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class InitializeBallotBox extends FaceToFaceCommand {
	InitializeResponse initializeResponse;
	AuthenticatedUserModel currentUser;
	String poolWorkerPassword;
	String poolingStationId;
	int poolingStationPort;

	InitializeBallotBox(this.initializeResponse, this.currentUser, this.poolWorkerPassword, this.poolingStationId, this.poolingStationPort);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['initializeResponse'] = this.initializeResponse.toJson();
		json['currentUser'] = this.currentUser.toJson();
		json['poolWorkerPassword'] = this.poolWorkerPassword;
		json['poolingStationId'] = this.poolingStationId;
		json['poolingStationPort'] = this.poolingStationPort;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.initializeResponse = InitializeResponse.create(json['initializeResponse']);
		this.currentUser = AuthenticatedUserModel.create(json['currentUser']);
		this.poolWorkerPassword = json['poolWorkerPassword'];
		this.poolingStationId = json['poolingStationId'];
		this.poolingStationPort = json['poolingStationPort'];
	}

	static InitializeBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new InitializeBallotBox(null,null,null,null,-1), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class GetBallotBoxStatus extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static GetBallotBoxStatus create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new GetBallotBoxStatus(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class SetBallotBoxStatus extends FaceToFaceCommand {
	int status;
	SetBallotBoxStatus(this.status);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['status'] = this.status;
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.status = json['status'];
	}

	static SetBallotBoxStatus create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new SetBallotBoxStatus(0), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class VoterToBallotBox extends FaceToFaceCommand {
	VoterModel voter;
	VoterToBallotBox(this.voter);

	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['voter'] = this.voter.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.voter = VoterModel.create(json['voter']);
	}

	static VoterToBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new VoterToBallotBox(null), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class CastVote extends FaceToFaceCommand {
	CastVotesRequestModel vote;

	CastVote(this.vote);
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		json['vote'] = this.vote.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
		this.vote = CastVotesRequestModel.create(json['vote']);
	}

	static CastVote create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new CastVote(null), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class CancelVote extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static CancelVote create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new CancelVote(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
class FinishBallotBox extends FaceToFaceCommand {
	Map<String, dynamic> toJson() {
		final Map<String, dynamic> json = super.toJson();
		return json;
	}

	fromJson(Map<String, dynamic> json) {
		super.fromJson(json);
	}

	static FinishBallotBox create(Map<String, dynamic> json) {
		var ret = FaceToFaceCommand.create(new FinishBallotBox(), json);
		if (json != null) ret.fromJson(json);
		return ret;
	}
}
